==> mocca_edc-0.1.9-py3-none-any.whl: mocca_auth/codenames/clinic.py <==
from edc_auth.codenames import clinic

clinic += [
    "mocca_lists.view_arvdrugs",
    "mocca_lists.view_arvregimens",
    "mocca_lists.view_clinicservices",
    "mocca_lists.view_conditions",
    "mocca_lists.view_dmtreatments",
    "mocca_lists.view_htntreatments",
    "mocca_lists.view_offstudyreasons",
    "mocca_lists.view_rxmodificationreasons",
    "mocca_lists.view_rxmodifications",
    "mocca_lists.view_visitreasons",
    "mocca_prn.add_endofstudy",
    "mocca_prn.add_losstofollowup",
    "mocca_prn.add_offschedule",
    "mocca_prn.add_onschedule",
    "mocca_prn.add_protocoldeviationviolation",
    "mocca_prn.change_endofstudy",
    "mocca_prn.change_losstofollowup",
    "mocca_prn.change_offschedule",
    "mocca_prn.change_onschedule",
    "mocca_prn.change_protocoldeviationviolation",
    "mocca_prn.delete_endofstudy",
    "mocca_prn.delete_losstofollowup",
    "mocca_prn.delete_offschedule",
    "mocca_prn.delete_onschedule",
    "mocca_prn.delete_protocoldeviationviolation",
    "mocca_prn.view_endofstudy",
    "mocca_prn.view_historicalendofstudy",
    "mocca_prn.view_historicallosstofollowup",
    "mocca_prn.view_historicaloffschedule",
    "mocca_prn.view_historicalonschedule",
    "mocca_prn.view_historicalprotocoldeviationviolation",
    "mocca_prn.view_losstofollowup",
    "mocca_prn.view_offschedule",
    "mocca_prn.view_onschedule",
    "mocca_prn.view_protocoldeviationviolation",
    "mocca_prn.view_unblindingrequestoruser",
    "mocca_prn.view_unblindingrevieweruser",
    "mocca_subject.add_cd4result",
    "mocca_subject.add_clinicalreview",
    "mocca_subject.add_clinicalreviewbaseline",
    "mocca_subject.add_complicationsbaseline",
    "mocca_subject.add_complicationsfollowup",
    "mocca_subject.add_dminitialreview",
    "mocca_subject.add_dmreview",
    "mocca_subject.add_drugrefilldm",
    "mocca_subject.add_drugrefillhiv",
    "mocca_subject.add_drugrefillhtn",
    "mocca_subject.add_drugsupplydm",
    "mocca_subject.add_drugsupplyhiv",
    "mocca_subject.add_drugsupplyhtn",
    "mocca_subject.add_familyhistory",
    "mocca_subject.add_glucose",
    "mocca_subject.add_healtheconomicsrevised",
    "mocca_subject.add_hivinitialreview",
    "mocca_subject.add_hivreview",
    "mocca_subject.add_htninitialreview",
    "mocca_subject.add_htnreview",
    "mocca_subject.add_hivmedicationadherence",
    "mocca_subject.add_dmmedicationadherence",
    "mocca_subject.add_htnmedicationadherence",
    "mocca_subject.add_indicators",
    "mocca_subject.add_medications",
    "mocca_subject.add_nextappointment",
    "mocca_subject.add_otherbaselinedata",
    "mocca_subject.add_reasonforvisit",
    "mocca_subject.add_subjectrequisition",
    "mocca_subject.add_subjectvisit",
    "mocca_subject.add_subjectvisitmissed",
    "mocca_subject.add_viralloadresult",
    "mocca_subject.change_cd4result",
    "mocca_subject.change_clinicalreview",
    "mocca_subject.change_clinicalreviewbaseline",
    "mocca_subject.change_complicationsbaseline",
    "mocca_subject.change_complicationsfollowup",
    "mocca_subject.change_dminitialreview",
    "mocca_subject.change_dmreview",
    "mocca_subject.change_drugrefilldm",
    "mocca_subject.change_drugrefillhiv",
    "mocca_subject.change_drugrefillhtn",
    "mocca_subject.change_drugsupplydm",
    "mocca_subject.change_drugsupplyhiv",
    "mocca_subject.change_drugsupplyhtn",
    "mocca_subject.change_familyhistory",
    "mocca_subject.change_glucose",
    "mocca_subject.change_healtheconomicsrevised",
    "mocca_subject.change_hivinitialreview",
    "mocca_subject.change_hivreview",
    "mocca_subject.change_htninitialreview",
    "mocca_subject.change_htnreview",
    "mocca_subject.change_hivmedicationadherence",
    "mocca_subject.change_dmmedicationadherence",
    "mocca_subject.change_htnmedicationadherence",
    "mocca_subject.change_indicators",
    "mocca_subject.change_medications",
    "mocca_subject.change_nextappointment",
    "mocca_subject.change_otherbaselinedata",
    "mocca_subject.change_reasonforvisit",
    "mocca_subject.change_subjectrequisition",
    "mocca_subject.change_subjectvisit",
    "mocca_subject.change_subjectvisitmissed",
    "mocca_subject.change_viralloadresult",
    "mocca_subject.delete_cd4result",
    "mocca_subject.delete_clinicalreview",
    "mocca_subject.delete_clinicalreviewbaseline",
    "mocca_subject.delete_complicationsbaseline",
    "mocca_subject.delete_complicationsfollowup",
    "mocca_subject.delete_dminitialreview",
    "mocca_subject.delete_dmreview",
    "mocca_subject.delete_drugrefilldm",
    "mocca_subject.delete_drugrefillhiv",
    "mocca_subject.delete_drugrefillhtn",
    "mocca_subject.delete_drugsupplydm",
    "mocca_subject.delete_drugsupplyhiv",
    "mocca_subject.delete_drugsupplyhtn",
    "mocca_subject.delete_familyhistory",
    "mocca_subject.delete_glucose",
    "mocca_subject.delete_healtheconomicsrevised",
    "mocca_subject.delete_hivinitialreview",
    "mocca_subject.delete_hivreview",
    "mocca_subject.delete_htninitialreview",
    "mocca_subject.delete_htnreview",
    "mocca_subject.delete_hivmedicationadherence",
    "mocca_subject.delete_dmmedicationadherence",
    "mocca_subject.delete_htnmedicationadherence",
    "mocca_subject.delete_indicators",
    "mocca_subject.delete_medications",
    "mocca_subject.delete_nextappointment",
    "mocca_subject.delete_otherbaselinedata",
    "mocca_subject.delete_reasonforvisit",
    "mocca_subject.delete_subjectrequisition",
    "mocca_subject.delete_subjectvisit",
    "mocca_subject.delete_subjectvisitmissed",
    "mocca_subject.delete_viralloadresult",
    "mocca_subject.view_cd4result",
    "mocca_subject.view_clinicalreview",
    "mocca_subject.view_clinicalreviewbaseline",
    "mocca_subject.view_complicationsbaseline",
    "mocca_subject.view_complicationsfollowup",
    "mocca_subject.view_dminitialreview",
    "mocca_subject.view_dmreview",
    "mocca_subject.view_drugrefilldm",
    "mocca_subject.view_drugrefillhiv",
    "mocca_subject.view_drugrefillhtn",
    "mocca_subject.view_drugsupplydm",
    "mocca_subject.view_drugsupplyhiv",
    "mocca_subject.view_drugsupplyhtn",
    "mocca_subject.view_familyhistory",
    "mocca_subject.view_glucose",
    "mocca_subject.view_healtheconomicsrevised",
    "mocca_subject.view_historicalcd4result",
    "mocca_subject.view_historicalclinicalreview",
    "mocca_subject.view_historicalclinicalreviewbaseline",
    "mocca_subject.view_historicalcomplicationsbaseline",
    "mocca_subject.view_historicalcomplicationsfollowup",
    "mocca_subject.view_historicaldminitialreview",
    "mocca_subject.view_historicaldmreview",
    "mocca_subject.view_historicalfamilyhistory",
    "mocca_subject.view_historicalglucose",
    "mocca_subject.view_historicalhealtheconomicsrevised",
    "mocca_subject.view_historicalhivinitialreview",
    "mocca_subject.view_historicalhivreview",
    "mocca_subject.view_historicalhtninitialreview",
    "mocca_subject.view_historicalhtnreview",
    "mocca_subject.view_historicalhivmedicationadherence",
    "mocca_subject.view_historicaldmmedicationadherence",
    "mocca_subject.view_historicalhtnmedicationadherence",
    "mocca_subject.view_historicalindicators",
    "mocca_subject.view_historicalmedications",
    "mocca_subject.view_historicalnextappointment",
    "mocca_subject.view_historicalotherbaselinedata",
    "mocca_subject.view_historicalreasonforvisit",
    "mocca_subject.view_historicalsubjectrequisition",
    "mocca_subject.view_historicalsubjectvisit",
    "mocca_subject.view_historicalsubjectvisitmissed",
    "mocca_subject.view_historicalviralloadresult",
    "mocca_subject.view_hivinitialreview",
    "mocca_subject.view_hivreview",
    "mocca_subject.view_htninitialreview",
    "mocca_subject.view_htnreview",
    "mocca_subject.view_hivmedicationadherence",
    "mocca_subject.view_dmmedicationadherence",
    "mocca_subject.view_htnmedicationadherence",
    "mocca_subject.view_indicators",
    "mocca_subject.view_medications",
    "mocca_subject.view_nextappointment",
    "mocca_subject.view_otherbaselinedata",
    "mocca_subject.view_reasonforvisit",
    "mocca_subject.view_subjectrequisition",
    "mocca_subject.view_subjectvisit",
    "mocca_subject.view_subjectvisitmissed",
    "mocca_subject.view_viralloadresult",
]
clinic.sort()

==> mocca_edc-0.1.12-py3-none-any.whl: mocca_auth/codenames/clinic.py <==
from edc_auth.codenames import clinic

clinic += [
    "mocca_lists.view_arvdrugs",
    "mocca_lists.view_arvregimens",
    "mocca_lists.view_clinicservices",
    "mocca_lists.view_conditions",
    "mocca_lists.view_dmtreatments",
    "mocca_lists.view_htntreatments",
    "mocca_lists.view_choltreatments",
    "mocca_lists.view_offstudyreasons",
    "mocca_lists.view_rxmodificationreasons",
    "mocca_lists.view_rxmodifications",
    "mocca_lists.view_visitreasons",
    "mocca_prn.add_endofstudy",
    "mocca_prn.add_losstofollowup",
    "mocca_prn.add_offschedule",
    "mocca_prn.add_onschedule",
    "mocca_prn.add_protocoldeviationviolation",
    "mocca_prn.change_endofstudy",
    "mocca_prn.change_losstofollowup",
    "mocca_prn.change_offschedule",
    "mocca_prn.change_onschedule",
    "mocca_prn.change_protocoldeviationviolation",
    "mocca_prn.delete_endofstudy",
    "mocca_prn.delete_losstofollowup",
    "mocca_prn.delete_offschedule",
    "mocca_prn.delete_onschedule",
    "mocca_prn.delete_protocoldeviationviolation",
    "mocca_prn.view_endofstudy",
    "mocca_prn.view_historicalendofstudy",
    "mocca_prn.view_historicallosstofollowup",
    "mocca_prn.view_historicaloffschedule",
    "mocca_prn.view_historicalonschedule",
    "mocca_prn.view_historicalprotocoldeviationviolation",
    "mocca_prn.view_losstofollowup",
    "mocca_prn.view_offschedule",
    "mocca_prn.view_onschedule",
    "mocca_prn.view_protocoldeviationviolation",
    "mocca_prn.view_unblindingrequestoruser",
    "mocca_prn.view_unblindingrevieweruser",
    "mocca_subject.add_bloodresultsfbc",
    "mocca_subject.add_bloodresultslipid",
    "mocca_subject.add_cd4result",
    "mocca_subject.add_clinicalreview",
    "mocca_subject.add_clinicalreviewbaseline",
    "mocca_subject.add_complicationsbaseline",
    "mocca_subject.add_complicationsfollowup",
    "mocca_subject.add_dminitialreview",
    "mocca_subject.add_dmreview",
    "mocca_subject.add_drugrefilldm",
    "mocca_subject.add_drugrefillhiv",
    "mocca_subject.add_drugrefillhtn",
    "mocca_subject.add_drugrefillchol",
    "mocca_subject.add_drugsupplydm",
    "mocca_subject.add_drugsupplyhiv",
    "mocca_subject.add_drugsupplyhtn",
    "mocca_subject.add_drugsupplychol",
    "mocca_subject.add_glucose",
    "mocca_subject.add_glucosebaseline",
    "mocca_subject.add_hivinitialreview",
    "mocca_subject.add_hivreview",
    "mocca_subject.add_htninitialreview",
    "mocca_subject.add_cholinitialreview",
    "mocca_subject.add_htnreview",
    "mocca_subject.add_cholreview",
    "mocca_subject.add_hivmedicationadherence",
    "mocca_subject.add_dmmedicationadherence",
    "mocca_subject.add_htnmedicationadherence",
    "mocca_subject.add_cholmedicationadherence",
    "mocca_subject.add_indicators",
    "mocca_subject.add_medications",
    "mocca_subject.add_nextappointment",
    "mocca_subject.add_otherbaselinedata",
    "mocca_subject.add_patienthealth",
    "mocca_subject.add_subjectrequisition",
    "mocca_subject.add_subjectvisit",
    "mocca_subject.add_subjectvisitmissed",
    "mocca_subject.add_viralloadresult",
    "mocca_subject.change_bloodresultsfbc",
    "mocca_subject.change_bloodresultslipid",
    "mocca_subject.change_cd4result",
    "mocca_subject.change_clinicalreview",
    "mocca_subject.change_clinicalreviewbaseline",
    "mocca_subject.change_complicationsbaseline",
    "mocca_subject.change_complicationsfollowup",
    "mocca_subject.change_dminitialreview",
    "mocca_subject.change_dmreview",
    "mocca_subject.change_drugrefilldm",
    "mocca_subject.change_drugrefillhiv",
    "mocca_subject.change_drugrefillhtn",
    "mocca_subject.change_drugrefillchol",
    "mocca_subject.change_drugsupplydm",
    "mocca_subject.change_drugsupplyhiv",
    "mocca_subject.change_drugsupplyhtn",
    "mocca_subject.change_drugsupplychol",
    "mocca_subject.change_glucose",
    "mocca_subject.change_glucosebaseline",
    "mocca_subject.change_hivinitialreview",
    "mocca_subject.change_hivreview",
    "mocca_subject.change_htninitialreview",
    "mocca_subject.change_cholinitialreview",
    "mocca_subject.change_htnreview",
    "mocca_subject.change_cholreview",
    "mocca_subject.change_hivmedicationadherence",
    "mocca_subject.change_dmmedicationadherence",
    "mocca_subject.change_htnmedicationadherence",
    "mocca_subject.change_cholmedicationadherence",
    "mocca_subject.change_indicators",
    "mocca_subject.change_medications",
    "mocca_subject.change_nextappointment",
    "mocca_subject.change_otherbaselinedata",
    "mocca_subject.change_patienthealth",
    "mocca_subject.change_subjectrequisition",
    "mocca_subject.change_subjectvisit",
    "mocca_subject.change_subjectvisitmissed",
    "mocca_subject.change_viralloadresult",
    "mocca_subject.delete_bloodresultsfbc",
    "mocca_subject.delete_bloodresultslipid",
    "mocca_subject.delete_cd4result",
    "mocca_subject.delete_clinicalreview",
    "mocca_subject.delete_clinicalreviewbaseline",
    "mocca_subject.delete_complicationsbaseline",
    "mocca_subject.delete_complicationsfollowup",
    "mocca_subject.delete_dminitialreview",
    "mocca_subject.delete_dmreview",
    "mocca_subject.delete_drugrefilldm",
    "mocca_subject.delete_drugrefillhiv",
    "mocca_subject.delete_drugrefillhtn",
    "mocca_subject.delete_drugrefillchol",
    "mocca_subject.delete_drugsupplydm",
    "mocca_subject.delete_drugsupplyhiv",
    "mocca_subject.delete_drugsupplyhtn",
    "mocca_subject.delete_drugsupplychol",
    "mocca_subject.delete_glucose",
    "mocca_subject.delete_glucosebaseline",
    "mocca_subject.delete_hivinitialreview",
    "mocca_subject.delete_hivreview",
    "mocca_subject.delete_htninitialreview",
    "mocca_subject.delete_cholinitialreview",
    "mocca_subject.delete_htnreview",
    "mocca_subject.delete_cholreview",
    "mocca_subject.delete_hivmedicationadherence",
    "mocca_subject.delete_dmmedicationadherence",
    "mocca_subject.delete_htnmedicationadherence",
    "mocca_subject.delete_cholmedicationadherence",
    "mocca_subject.delete_indicators",
    "mocca_subject.delete_medications",
    "mocca_subject.delete_nextappointment",
    "mocca_subject.delete_otherbaselinedata",
    "mocca_subject.delete_patienthealth",
    "mocca_subject.delete_subjectrequisition",
    "mocca_subject.delete_subjectvisit",
    "mocca_subject.delete_subjectvisitmissed",
    "mocca_subject.delete_viralloadresult",
    "mocca_subject.view_bloodresultsfbc",
    "mocca_subject.view_bloodresultslipid",
    "mocca_subject.view_cd4result",
    "mocca_subject.view_clinicalreview",
    "mocca_subject.view_clinicalreviewbaseline",
    "mocca_subject.view_complicationsbaseline",
    "mocca_subject.view_complicationsfollowup",
    "mocca_subject.view_dminitialreview",
    "mocca_subject.view_dmreview",
    "mocca_subject.view_drugrefilldm",
    "mocca_subject.view_drugrefillhiv",
    "mocca_subject.view_drugrefillhtn",
    "mocca_subject.view_drugrefillchol",
    "mocca_subject.view_drugsupplydm",
    "mocca_subject.view_drugsupplyhiv",
    "mocca_subject.view_drugsupplyhtn",
    "mocca_subject.view_drugsupplychol",
    "mocca_subject.view_glucose",
    "mocca_subject.view_glucosebaseline",
    "mocca_subject.view_historicalbloodresultsfbc",
    "mocca_subject.view_historicalbloodresultslipid",
    "mocca_subject.view_historicalcd4result",
    "mocca_subject.view_historicalclinicalreview",
    "mocca_subject.view_historicalclinicalreviewbaseline",
    "mocca_subject.view_historicalcomplicationsbaseline",
    "mocca_subject.view_historicalcomplicationsfollowup",
    "mocca_subject.view_historicaldminitialreview",
    "mocca_subject.view_historicaldmreview",
    "mocca_subject.view_historicalglucose",
    "mocca_subject.view_historicalglucosebaseline",
    "mocca_subject.view_historicalhivinitialreview",
    "mocca_subject.view_historicalhivreview",
    "mocca_subject.view_historicalhtninitialreview",
    "mocca_subject.view_historicalcholinitialreview",
    "mocca_subject.view_historicalhtnreview",
    "mocca_subject.view_historicalcholreview",
    "mocca_subject.view_historicalhivmedicationadherence",
    "mocca_subject.view_historicaldmmedicationadherence",
    "mocca_subject.view_historicalhtnmedicationadherence",
    "mocca_subject.view_historicalcholmedicationadherence",
    "mocca_subject.view_historicalindicators",
    "mocca_subject.view_historicalmedications",
    "mocca_subject.view_historicalnextappointment",
    "mocca_subject.view_historicalotherbaselinedata",
    "mocca_subject.view_historicalpatienthealth",
    "mocca_subject.view_historicalsubjectrequisition",
    "mocca_subject.view_historicalsubjectvisit",
    "mocca_subject.view_historicalsubjectvisitmissed",
    "mocca_subject.view_historicalviralloadresult",
    "mocca_subject.view_hivinitialreview",
    "mocca_subject.view_hivreview",
    "mocca_subject.view_htninitialreview",
    "mocca_subject.view_cholinitialreview",
    "mocca_subject.view_htnreview",
    "mocca_subject.view_cholreview",
    "mocca_subject.view_hivmedicationadherence",
    "mocca_subject.view_dmmedicationadherence",
    "mocca_subject.view_htnmedicationadherence",
    "mocca_subject.view_cholmedicationadherence",
    "mocca_subject.view_indicators",
    "mocca_subject.view_medications",
    "mocca_subject.view_nextappointment",
    "mocca_subject.view_otherbaselinedata",
    "mocca_subject.view_patienthealth",
    "mocca_subject.view_subjectrequisition",
    "mocca_subject.view_subjectvisit",
    "mocca_subject.view_subjectvisitmissed",
    "mocca_subject.view_viralloadresult",
]
clinic.sort()
